mailr8575 - /branches/multi_structure/specific_fns/n_state_model.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 22, 2009 - 10:28:
Author: bugman
Date: Thu Jan 22 10:28:55 2009
New Revision: 8575

URL: http://svn.gna.org/viewcvs/relax?rev=8575&view=rev
Log:
Bug fix for __update_model().  cdp.structure.num_structures() no longer 
exists.


Modified:
    branches/multi_structure/specific_fns/n_state_model.py

Modified: branches/multi_structure/specific_fns/n_state_model.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/multi_structure/specific_fns/n_state_model.py?rev=8575&r1=8574&r2=8575&view=diff
==============================================================================
--- branches/multi_structure/specific_fns/n_state_model.py (original)
+++ branches/multi_structure/specific_fns/n_state_model.py Thu Jan 22 
10:28:55 2009
@@ -809,11 +809,11 @@
         if not hasattr(cdp, 'params'):
             cdp.params = []
 
         # Determine the number of states, if not already set.
not already set.
         if not hasattr(cdp, 'N'):
             # Set the number.
             if hasattr(cdp, 'structure'):
-                cdp.N = cdp.structure.num_structures()
+                cdp.N = cdp.structure.num_models()
 
             # Otherwise return as the rest cannot be updated without N.
             else:
@@ -809,11 +809,11 @@
             cdp.params = []
 
-        # Determine the number of states, if not already set.
+        # Determine the number of states (loaded as structural models), if 
not already set.
         if not hasattr(cdp, 'N'):




Related Messages


Powered by MHonArc, Updated Thu Jan 22 11:00:04 2009